pub struct LibTarget {Show 13 fields
pub name: Option<Spanned<String>>,
pub path: Option<Spanned<String>>,
pub test: Option<Spanned<bool>>,
pub doctest: Option<Spanned<bool>>,
pub bench: Option<Spanned<bool>>,
pub doc: Option<Spanned<bool>>,
pub plugin: Option<Spanned<bool>>,
pub proc_macro: Option<Spanned<bool>>,
pub harness: Option<Spanned<bool>>,
pub edition: Option<Spanned<Edition>>,
pub crate_type: Option<Spanned<Vec<String>>>,
pub required_features: Option<Spanned<Vec<String>>>,
pub doc_scrape_examples: Option<Spanned<bool>>,
}Expand description
Library target configuration from [lib].
Fields
name: Option<Spanned<String>>The name of the library (defaults to package name with hyphens replaced by underscores).
path: Option<Spanned<String>>The source file of the target, relative to Cargo.toml.
test: Option<Spanned<bool>>Whether the target is tested by default by cargo test.
doctest: Option<Spanned<bool>>Whether documentation examples are tested by cargo test.
bench: Option<Spanned<bool>>Whether the target is benchmarked by default by cargo bench.
doc: Option<Spanned<bool>>Whether the target is included in cargo doc output.
plugin: Option<Spanned<bool>>Deprecated and unused.
proc_macro: Option<Spanned<bool>>Whether the library is a procedural macro.
harness: Option<Spanned<bool>>Whether to use the libtest harness for #[test] functions.
edition: Option<Spanned<Edition>>The Rust edition the target will use.
crate_type: Option<Spanned<Vec<String>>>The crate types to generate (e.g., lib, rlib, dylib, cdylib, staticlib).
required_features: Option<Spanned<Vec<String>>>Features required for the target to be built.
doc_scrape_examples: Option<Spanned<bool>>Whether Rustdoc should scrape examples from this target.